# Changelog

<!--next-version-placeholder-->

## v0.1.3 (2022-07-09)
### Documentation
* Add example ([`d86458c`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/d86458c3bac2824d13d2f6bc9541221448b97d88))

## v0.1.2 (2022-07-09)
### Fix
* A bunch of hot fix ([`4f57944`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/4f57944d3e08e90d823c8237f861743d4c90c9be))

## v0.1.1 (2022-07-07)
### Fix
* No hashtags convertion in code_blocks ([`7742922`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/7742922f8c85208907c306337cb7b8fb245b0d79))

## v0.1.0 (2022-06-28)
### Feature
* Create the plugin ([`702dddf`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/702dddf8490bfd82fe8cdd8b77ce65ea46373a0c))

### Documentation
* Create and complete readme ([`2016003`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/2016003eb8c319be2cb419dd4e762c66ddf8ec74))
